///[Data]服务端数据交互
(function(data) {

	/**
	 * ///[data:query]查询数据
	 * 
	 * @param {String} queryUrl : 服务端查询数据URL
	 * @param {Object} queryInfo : 查询信息对象
	 * @param {function(data)} successCB : 查询成功回调函数，data为查询数据对象
	 * @param {function(err)} errorCB : 查询失败回调函数，err为错误信息
	 **/
	data.query = function(queryUrl, queryInfo, successCB, errorCB) {
		___debug___ && console.log(___js_func___("Data.js","data.query"),["queryUrl: "+queryUrl,"queryInfo: "+JSON.stringify(queryInfo)]);

		successCB = successCB || mui.noop;///设置缺省参数
		errorCB = errorCB || mui.noop;///设置缺省参数
		
		///Ajax请求
		console.log("@@@data.query:Ajax请求 $$$queryUrl:"+queryUrl);
		console.log("@@@data.query:Ajax请求 $$$queryInfo:"+JSON.stringify(queryInfo));

		mui.ajax(queryUrl,{
		  	data:queryInfo,
			dataType:'json',
			type:'get',
			timeout:910000,
            success:function(data){
            	console.log("@@@Ajax请求成功 $$$data:"+JSON.stringify(data));
				if(data.result>0){
					successCB(data.data);
				}else{
					errorCB(data.reason);
				}
            },
            error:function(xhr,type,errorThrown){
                //异常处理；
                console.log("Error:获取Ajax返值失败!");
                console.log(xhr.status);
                console.log(xhr.responseText);
                console.log(type);
                console.log(errorThrown);
           }
  		});
  	};

	/**
	 * ///[data:post]提交post请求到服务端
	 *
	 * 所有post请求都先校验Token，如果Token无效则不请求。
	 * 
	 * @param {String} postUrl : Post提交URL
	 * @param {Object} postInfo : Post提交信息对象
	 * @param {Integer} uid : 用户uid
	 * @param {function()} successCB : post成功回调函数
	 * @param {function(err)} errorCB : post失败回调函数，err为错误信息
	 **/
	data.post = function(postUrl, postInfo, uid, successCB, errorCB) {
		___debug___ && console.log(___js_func___("Data.js","data.post"),["postUrl: "+postUrl,"postInfo: "+JSON.stringify(postInfo)]);

		successCB = successCB || mui.noop;///设置缺省参数
		errorCB = errorCB || mui.noop;///设置缺省参数
		
		///校验Token，如果Token无效则不请求
		var token = Auth.getToken();
		if(!token) errorCB("Token无效");
		var post_info = {"uid":uid, "token":token,"postInfo":postInfo};///拼装post请求信息对象
		
		///Ajax请求
		console.log("@@@data.post:Ajax请求 $$$postUrl:"+postUrl);
		console.log("@@@data.post:Ajax请求 $$$post_info"+JSON.stringify(post_info));

		mui.ajax(postUrl, {
			data: post_info,
			dataType: 'json',
			type: 'post',
			timeout: 10000,
			success: function(data) {
				console.log("@@@data.post:Ajax请求成功 $$$data:"+JSON.stringify(data));
				if(data.result=="0"){
					successCB();
				}else{
					errorCB(data.reason);
				}
			},
			error: function(xhr, type, errorThrown) {
				//异常处理；
				console.log("Error：Ajax获取返值失败！");
				console.log(xhr.status);
				console.log(xhr.responseText);
				console.log(type);
				console.log(errorThrown);
				errorCB("Error:获取Ajax返值失败!");
			}
		});
  	};

	/**
	 * ///[data:delete]请求到服务端删除某记录
	 * 
	 * @param {String} deleteUrl : Post提交URL
	 * @param {Object} deleteInfo : Post提交信息对象
	 * @param {Integer} uid : 用户uid
	 * @param {function()} successCB : delete成功回调函数
	 * @param {function(err)} errorCB : delete失败回调函数，err为错误信息
	 **/
	data.delete = function(deleteUrl, deleteInfo, uid, successCB, errorCB) {
		___debug___ && console.log(___js_func___("Data.js","data.delete"),["deleteUrl: "+deleteUrl,"deleteInfo: "+JSON.stringify(deleteInfo)]);

		successCB = successCB || mui.noop;///设置缺省参数
		errorCB = errorCB || mui.noop;///设置缺省参数
		
		///校验Token，如果Token无效则不请求
		var token = Auth.getToken();
		if(!token) errorCB("Token无效");
		var delete_info = {"uid":uid, "token":token,"deleteInfo":deleteInfo};///拼装post请求信息对象
		
		///Ajax请求
		console.log("@@@data.delete:Ajax请求 $$$deleteUrl:"+deleteUrl);
		console.log("@@@data.delete:Ajax请求 $$$delete_info"+JSON.stringify(delete_info));

		mui.ajax(deleteUrl, {
			data: delete_info,
			dataType: 'json',
			type: 'post',
			timeout: 10000,
			success: function(data) {
				console.log("@@@data.delete:Ajax请求成功 $$$data:"+JSON.stringify(data));
				if(data.result=="0"){
					successCB();
				}else{
					errorCB(data.reason);
				}
			},
			error: function(xhr, type, errorThrown) {
				//异常处理；
				console.log("Error：Ajax获取返值失败！");
				console.log(xhr.status);
				console.log(xhr.responseText);
				console.log(type);
				console.log(errorThrown);
				errorCB("Error:获取Ajax返值失败!");
			}
		});
  	};
})(window.Data = {});