///[UpdateVersion]版本检查更新
(function(updateVersion) {

	///服务端返回的更新信息，需根据应用情况在服务端自定义
	///示例：{"version":"1.0", "description":"有全新版本，请下载！", "updateUrl":"http://192.168.0.102/app/a.apk", "installPath":"_doc/update/"}
	var updateUrl = null;
	var installPath = null;		///应用的安装路径
	var newVersion = null;		///更新的版本号
	var currentVersion = null;	///当前的版本号
	

	/**
	 * ///[updateVersion:checkUpdate]版本检查更新
	 * 
	 * 首先获取应用的当前版本号和获取更新的版本号，然后比较，
	 * 如果版本较新则弹出对话框询问用户是否更新，否则不更新。
	 * 
	 * @param {Boolean} isSilent : 
	 * 		true: 静默方式。没有新版本时不显示提示消息；有新版本时也静默下载
	 * 		false:非静默方式。没有新版本时显示提示消息；有新版本时也非静默下载
	 */
	updateVersion.checkUpdate = function(isSilent) {
		___debug___ && console.log(___js_func___("UpdateJSON.js","updateVersion.checkUpdate",["isSilent: "+isSilent]));

		///获取本地应用的版本号
		plus.runtime.getProperty(plus.runtime.appid, function(info) {
			console.log("@@@updateVersion.checkUpdate@plus.runtime.getProperty $$$info.appid:" + info.appid);
			console.log("@@@updateVersion.checkUpdate:plus.runtime.getProperty $$$info.name:" + info.name);
			console.log("@@@updateVersion.checkUpdate@plus.runtime.getProperty $$$info.version:" + info.version);
			currentVersion = info.version;
		});

		///Ajax请求，获取更新的版本号，然后比较
		mui.ajax(UPDATE_INFO_URL, {
			dataType: 'json',
			type: 'get',
			timeout: 10000,
			success: function(data) {
				newVersion = data.version;
				updateUrl = data.updateUrl;
				installPath = data.installPath;
				console.log("@@@updateVersion.checkUpdate@Ajax请求成功 $$$UPDATE_INFO_URL:"+UPDATE_INFO_URL);
				console.log("@@@updateVersion.checkUpdate@Ajax请求成功 $$$JSON.stringify(data)"+JSON.stringify(data));
				
				removeRecursively(installPath);///删除安装文件
		        
				///[UpdateVersion:compareVersion]比较版本，如果版本较新则弹出对话框询问用户是否更新，否则不更新
				console.log("@@@updateVersion.checkUpdate@compareVersion $$$currentVersion:"+currentVersion+"  $$$newVersion:"+newVersion);
				if (compareVersion(currentVersion, newVersion)) {

					///弹出对话框，由用户选择是否更新
					plus.nativeUI.confirm("检测到有新版本，是否更新?", function(e) {
						if (e.index == 0) {
							///下载更新
							updateVersion.downloadUpdate(isSilent);
						}
					}, "", ["立即更新", "取消"]);

				} else {
					if (!isSilent) plus.nativeUI.toast("没有检测到新版本");
				}
			},
			error: function(xhr, type, errorThrown) {
				//异常处理；
				console.log("Error:获取Ajax返值失败!");
				console.log(xhr.status);
				console.log(xhr.responseText);
				console.log(type);
				console.log(errorThrown);
				
				if (!isSilent) plus.nativeUI.alert("获取应用更新信息失败");
			}
		});
	}
	
	/**
	 * ///[updateVersion:downloadUpdate]下载更新
	 * 
	 * @param {Boolean} isSilent : 
	 * 		true: 静默方式。没有新版本时不显示提示消息；有新版本时也静默下载
	 * 		false:非静默方式。没有新版本时显示提示消息；有新版本时也非静默下载
	 */
	updateVersion.downloadUpdate = function(isSilent) {
		___debug___ && console.log(___js_func___("UpdateVersion..js","UpdateVersion.downloadUpdate",["isSilent: "+isSilent]));
		
		var w;
		if (!isSilent) {
			w = plus.nativeUI.showWaiting("　　 开始下载...　　");
		}
		
		///删除下载文件
//		plus.downloader.clear();
		plus.io.resolveLocalFileSystemURL(installPath, function(entry) {
		    entry.removeRecursively(function() {
			//递归删除成功
            }, function() {

            });
        }, function(e) {

        });
		
		var options = {
			filename: installPath,
			timeout:10///[BUG???不生效！依然是约3分钟才timeout]
		};

		var dtask = plus.downloader.createDownload(updateUrl, options, function(d, status) {
			if (status == 200) {
				console.log("@@@updateVersion.downloadUpdate@plus.downloader.createDownload ###应用下载成功  $$$filename:" + d.filename);
				setTimeout(updateVersion.installUpdate(d.filename, isSilent), 3000); // 安装应用文件
			} else {
				console.log("@@@updateVersion.downloadUpdate@plus.downloader.createDownload ###应用下载失败");
				if (!isSilent) {
					plus.nativeUI.alert("应用下载失败");
				}
			}
		});
		
		var i = 0, progress = 0;
		dtask.addEventListener("statechanged", function(task, status) {
			switch (task.state) {
				case 1: // 开始建立网络连接，发送请求到服务器并等待服务器的响应
					!isSilent && w.setTitle("　　 建立网络连接...　　 ");
					break;
				case 2: // 已连接到服务器，但如果未找到下载的文件，则反复循环 task.state=2，status=404
					!isSilent && w.setTitle("　　 已连接到服务器...　　 ");
					break;
				case 3: // 传输数据中，在传输过程中不断触发此状态事件
					progress = Math.round(task.downloadedSize / task.totalSize * 100);
					
					///[BUG!!!下载时时而出现错误Uncaught RangeError: Maximum call stack size exceeded]
					///解决方法：设置步进长度，避免频繁调用、耽误时间
					if (progress - i >= 1) {///进度条更新步长，默认为5
                        i = progress;
						console.log(progress);
						!isSilent && w.setTitle("　　 已下载" + progress + "%　　 ");
						Notification.NotificationUtil.setProgress(progress); //插件调用
                    }

					break;
				case 4: // 下载任务成功或失败都会设置为此状态
					console.log("@@@dtask.statechanged ###下载任务成功或失败");
					!isSilent && w.close();
					Notification.NotificationUtil.compProgressNotification("@@@dtask.statechanged ###下载完成"); //插件调用
					break;
			}
		});
		
		dtask.start();
	}

	/**
	 * ///[updateVersion:installUpdate]安装更新
	 * 
	 * @param {String} path : APP应用所在目录
	 * @param {Boolean} isSilent : 
	 * 		true: 静默方式。没有新版本时不显示提示消息；有新版本时也静默下载
	 * 		false:非静默方式。没有新版本时显示提示消息；有新版本时也非静默下载
	 */
	updateVersion.installUpdate = function(path, isSilent) {
		___debug___ && console.log(___js_func___("UpdateVersion.js","updateVersion.installUpdate",["path: "+path,"isSilent: "+isSilent]));
		
		if (!isSilent) {
			plus.nativeUI.showWaiting("在线升级，正在安装...");
		}
		plus.runtime.install(path, {force:true}, function() {
			if (!isSilent) {
				plus.nativeUI.closeWaiting();
				///自动在线升级并重启
				plus.nativeUI.alert("在线升级结束，重启应用", function() {
					plus.runtime.restart();
				});
			}
			console.log("@@@updateVersion.installUpdate ###安装成功");
			Notification.NotificationUtil.clearAllNotification();
			
			///更新后设置启动引导页面
			setSetting("$skip_lauch_flag");

		}, function(e) {
			console.log("@@@updateVersion.installUpdate ###安装失败 $$$e"+JSON.stringify(e));
			Notification.NotificationUtil.clearAllNotification();
			
			if (!isSilent) {
				plus.nativeUI.closeWaiting();
				plus.nativeUI.alert("在线升级，安装失败");
			}
		});
	}
	
	/**
	 * ///[compareVersion]比较版本大小
	 * 
	 * @param {String} ov : 以前版本号
	 * @param {String} nv ：当前版本号
	 * @return {Boolean} : 如果新版本nv大于旧版本ov则返回true，小于则返回false，相当则返回undefined
	 */
	function compareVersion(ov, nv) {
		if (!ov || !nv || ov == "" || nv == "") {
			return false;
		}
		var b = false,
			ova = ov.split(".", 4),
			nva = nv.split(".", 4);
		for (var i = 0; i < ova.length && i < nva.length; i++) {
			var so = ova[i],
				no = parseInt(so),
				sn = nva[i],
				nn = parseInt(sn);
			if (nn > no || sn.length > so.length) {
				return true;
			} else if (nn < no) {
				return false;
			}
		}
		if (nva.length > ova.length && 0 == nv.indexOf(ov)) {
			return true;
		}
	}

}(window.UpdateVersion = {}));