/**
 * ///火星坐标系 (GCJ-02) 与百度坐标系 (BD-09) 的转换算法 
 * 
 * （参考：http://www.aiuxian.com/article/p-2504647.html）
 **/
var M_PI = 3.14159265358979324;  
var a = 6378245.0;  
var ee = 0.00669342162296594323; 
var x_pi = M_PI * 3000.0 / 180.0;
function gcj2bd(poi) {  
    var poi2 = {};  
    var x = poi.lng, y = poi.lat;  
    var z = Math.sqrt(x * x + y * y) + 0.00002 * Math.sin(y * x_pi);  
    var theta = Math.atan2(y, x) + 0.000003 * Math.cos(x * x_pi);  
    poi2.lng = z * Math.cos(theta) + 0.0065;  
    poi2.lat = z * Math.sin(theta) + 0.006;  
    return poi2;  
}  
  
function bd2gcj(poi) {  
    var poi2 = {};  
    var x = poi.lng - 0.0065, y = poi.lat - 0.006;  
    var z = Math.sqrt(x * x + y * y) - 0.00002 * Math.sin(y * x_pi);  
    var theta = Math.atan2(y, x) - 0.000003 * Math.cos(x * x_pi);  
    poi2.lng = z * Math.cos(theta);  
    poi2.lat = z * Math.sin(theta);  
    return poi2;  
}  

/**
 * ///[setSetting]设置本地存储
 * 
 * @param {String} key : 本地存储的键名，如"$appinfo"
 * @param {Object} setting : 本地存储的对象，如果为空代表要清除该键值key的对象
 **/
setSetting = function(key, setting){
	if(setting){
		localStorage.setItem(key, JSON.stringify(setting));
	}else{
		localStorage.removeItem(key);
	}
	___debug___ && console.log("@@@setSetting ###存储到本地 "+key+":"+localStorage.getItem(key));
}

/**
 * ///[getSetting]设置本地存储
 * 
 * @param {String} key : 本地存储的键名，如"$appinfo"
 * @param {Object} setting : 本地存储的对象，如果为空代表要清除该键值key的对象
 * 
 * @return {Object} : 返回本地存储的对象
 **/
getSetting = function(key){
	var settingText = localStorage.getItem(key);
	___debug___ && console.log("@@@getSetting ###从本地读取 "+key+":"+settingText);
	return JSON.parse(settingText);
}

/**
 * ///[isFileExist]判断本地文件是否存在
 * 
 * @param {String} pathfilename : 本地存储全目录文件名，如"_doc/avatar_1.jpg"
 * @param {Integer} uid : 用户uid
 * @param {function(c)} callback : 回调函数，如果文件存在c返回file对象，不存在则c返回false；如其目录不存在则返回null
 **/
isFileExist = function(pathfilename, callback){
	if(pathfilename.lastIndexOf("/")<0) callback(null);
	var l = pathfilename.lastIndexOf("/")+1;
	var path = pathfilename.substring(0, l);
	var filename = pathfilename.substring(l, pathfilename.length);
	
//	console.log("===="+l);
//	console.log("===="+path);
//	console.log("===="+filename);
	plus.io.resolveLocalFileSystemURL(path, function(entry) {
		entry.getFile(filename, {}, function(file) {
			//文件已存在
			callback(file);
		}, function() {
			//文件不存在
			callback(false);
		});
	}, function(file) {
		callback(null);
	})
}

/**
 * ///[removeRecursively]判断本地目录其下的所有文件及子目录
 * 
 * @param {String} pathfilename : 本地存储全目录文件名，如"_doc/avatar_1.jpg"
 **/
removeRecursively = function(pathfilename){
	plus.io.resolveLocalFileSystemURL(pathfilename, function(entry) {
	    entry.removeRecursively(function(e) {///因目录中存在文件，所以remove方法无法删除！
			//删除成功
			console.log("@@@removeRecursively ###删除安装文件成功");
        }, function(file ) {
			console.log("@@@removeRecursively ###删除安装文件失败:"+JSON.stringify(file));
        });
    }, function(file) {
		console.log("@@@removeRecursively ###文件操作无效:"+JSON.stringify(file));
    });
}

/**
 * ///[randomNum]生成N位数字随机数
 * 
 * @param {Integer} n : N位
 * @return {Integer} : N位整数
 **/
function randomNum(n) {
	var t = '';
	for (var i = 0; i < n; i++) {
		t += Math.floor(Math.random() * 10);
	}
	return t;
}

/**
 * ///[formatTimestamp]格式化时间戳
 * 
 * @param {Timestamp} t : 时间戳（不带毫秒）
 * @return {String} : 格式化的时间字符串，比如"2016-3-8 21:53:53"
 **/
function formatTimestamp(t) {
	var d = new Date(t * 1000);    //根据时间戳生成的时间对象
	return	(d.getFullYear()) + "-" + 
           (d.getMonth() + 1) + "-" +
           (d.getDate()) + " " + 
           (d.getHours()) + ":" + 
           (d.getMinutes()) + ":" + 
           (d.getSeconds());
}

/**
 * ///[secondCounter]秒倒计时器
 * 
 * @param {Integer} wait : 计时总秒数
 * @param {function()} secondCB : 每秒回调函数
 * @param {function()} completeCB : 总秒数倒计时结束时的回调函数
 * 
 * 另外，可以考虑用setInterval()来实现
 **/
function secondCounter(wait, secondCB, completeCB) {
	secondCB(wait);
	wait--;
	if (wait < 0)
		completeCB();
	else
		setTimeout(function() {
			secondCounter(wait, secondCB, completeCB);
		},
		1000);
}


/**
 * ///[verifyMobile]校验手机号码
 **/
function verifyMobile(number) {
	return /^1[3|5|8][0-9]\d{4,8}$/.test(number);
}

/**
 * ///[verifyQQ:校验QQ号（5-16位数字）
 **/
function verifyQQ(code) {
	return /^[1-9]{1}[0-9]{4,15}$/.test(code);
}

/**
 * ///[verifyWechat:校验微信号（5位以上大小写字母、数字、下划线）
 **/
function verifyWechat(code) {
	return /^[a-zA-Z\d_]{5,}$/.test(code);
}

/**
 * ///[verifySmscode:校验手机验证码（6位数字）
 **/
function verifySmscode(code) {
	return /^[0-9]{6}$/.test(code);
}

/**
 * ///[verifyPassword]校验密码（6位以上大小写字母、数字、特殊字符）
 **/
function verifyPassword(password) {
	return /^[\@A-Za-z0-9_\!\#\$\%\^\&\*\.\~\[\]\{\}\-\+\=]{6,22}$/.test(password);
}

/**
 * ///[verifyUsername]校验用户名（大小写字母、数字、中文、下划线）
 **/
function verifyUsername(username) {
	return /^(?!_)(?!.*?_$)[a-zA-Z0-9_\u4e00-\u9fa5]+$/.test(username);
}

/**
 * ///[trim]去掉字符串前后空格等不显示特殊字符（JS中没有trim函数）
 **/
function trim(str){   
    str = str.replace(/^(\s|\u00A0)+/,'');   
    for(var i=str.length-1; i>=0; i--){   
        if(/\S/.test(str.charAt(i))){   
            str = str.substring(0, i+1);   
            break;   
        }   
    }   
    return str;   
}

/**
 * ///[template]模板解析
 * 
 * @param {String} args : 
 * 有两种调用方式，结果都是"我是loogn，今年22了"：
 * 		var template1="我是{0}，今年{1}了";
 * 		var template2="我是{name}，今年{age}了";
 * 		var result1=template1.template("loogn",22);
 * 		var result2=template2.template({name:"loogn",age:22});
 * 
 * （参考：http://www.cnblogs.com/loogn/archive/2011/06/20/2085165.html）
 **/
String.prototype.template = function(args) {
    var result = this;
    if (arguments.length > 0) {    
        if (arguments.length == 1 && typeof (args) == "object") {
            for (var key in args) {
                if(args[key]!=undefined){
                    var reg = new RegExp("({" + key + "})", "g");
                    result = result.replace(reg, args[key]);
                }
            }
        }
        else {
            for (var i = 0; i < arguments.length; i++) {
                if (arguments[i] != undefined) {
                    ///var reg = new RegExp("({[" + i + "]})", "g");///[BUG!!!在索引大于9时会有问题]
　　　　　　　　　　　　var reg= new RegExp("({)" + i + "(})", "g");
                    result = result.replace(reg, arguments[i]);
                }
            }
        }
    }
    return result;
}

